@@ -5,7 +5,6 @@ package command
 
 import (
 	"fmt"
-	"io/ioutil"
 	"math"
 	"os"
 	"path/filepath"
@@ -1009,9 +1008,9 @@ func (fc fileCheck) verify(t *testing.T, dir string) {
 		}
 	}
 	for file, expectedContent := range fc.expectedContent {
-		content, err := ioutil.ReadFile(filepath.Join(dir, file))
+		content, err := os.ReadFile(filepath.Join(dir, file))
 		if err != nil {
-			t.Fatalf("ioutil.ReadFile: %v", err)
+			t.Fatalf("os.ReadFile: %v", err)
 		}
 		if diff := cmp.Diff(expectedContent, string(content)); diff != "" {
 			t.Errorf("content of %s differs: %s", file, diff)
