@@ -1,6 +1,11 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: MPL-2.0
+
 package fix
 
 import (
+	"strings"
+
 	"github.com/mitchellh/mapstructure"
 )
 
@@ -8,6 +13,12 @@ import (
 // template in a Amazon builder
 type FixerAmazonShutdownBehavior struct{}
 
+func (FixerAmazonShutdownBehavior) DeprecatedOptions() map[string][]string {
+	return map[string][]string{
+		"*amazon*": []string{"shutdown_behaviour"},
+	}
+}
+
 func (FixerAmazonShutdownBehavior) Fix(input map[string]interface{}) (map[string]interface{}, error) {
 	// The type we'll decode into; we only care about builders
 	type template struct {
@@ -31,7 +42,7 @@ func (FixerAmazonShutdownBehavior) Fix(input map[string]interface{}) (map[string
 			continue
 		}
 
-		if builderType != "amazon-ebs" && builderType != "amazon-ebsvolume" && builderType != "amazon-instance" && builderType != "amazon-chroot" {
+		if !strings.HasPrefix(builderType, "amazon-") {
 			continue
 		}
 
