@@ -7,7 +7,6 @@ import (
 	"bytes"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -76,7 +75,7 @@ func (f *HCL2Formatter) Format(path string) (int, hcl.Diagnostics) {
 		return f.formatFile(path, diags, bytesModified)
 	}
 
-	fileInfos, err := ioutil.ReadDir(path)
+	fileInfos, err := os.ReadDir(path)
 	if err != nil {
 		diag := &hcl.Diagnostic{
 			Severity: hcl.DiagError,
@@ -129,7 +128,7 @@ func (f *HCL2Formatter) processFile(filename string) ([]byte, error) {
 		}
 	}
 
-	inSrc, err := ioutil.ReadAll(in)
+	inSrc, err := io.ReadAll(in)
 	if err != nil {
 		return nil, fmt.Errorf("failed to read %s: %s", filename, err)
 	}
@@ -158,7 +157,7 @@ func (f *HCL2Formatter) processFile(filename string) ([]byte, error) {
 		if filename == "-" {
 			_, _ = f.Output.Write(outSrc)
 		} else {
-			if err := ioutil.WriteFile(filename, outSrc, 0644); err != nil {
+			if err := os.WriteFile(filename, outSrc, 0644); err != nil {
 				return nil, err
 			}
 		}
@@ -178,14 +177,14 @@ func (f *HCL2Formatter) processFile(filename string) ([]byte, error) {
 // bytesDiff returns the unified diff of b1 and b2
 // Shamelessly copied from Terraform's fmt command.
 func bytesDiff(b1, b2 []byte, path string) (data []byte, err error) {
-	f1, err := ioutil.TempFile("", "")
+	f1, err := os.CreateTemp("", "")
 	if err != nil {
 		return
 	}
 	defer os.Remove(f1.Name())
 	defer f1.Close()
 
-	f2, err := ioutil.TempFile("", "")
+	f2, err := os.CreateTemp("", "")
 	if err != nil {
 		return
 	}
