@@ -5,7 +5,7 @@ package packer
 
 import (
 	"bytes"
-	"io/ioutil"
+	"io"
 	"testing"
 
 	"golang.org/x/sync/errgroup"
@@ -16,10 +16,10 @@ import (
 func TestProgressTracking_open_close(t *testing.T) {
 	var bar *UiProgressBar
 
-	tracker := bar.TrackProgress("1,", 1, 42, ioutil.NopCloser(nil))
+	tracker := bar.TrackProgress("1,", 1, 42, io.NopCloser(nil))
 	tracker.Close()
 
-	tracker = bar.TrackProgress("2,", 1, 42, ioutil.NopCloser(nil))
+	tracker = bar.TrackProgress("2,", 1, 42, io.NopCloser(nil))
 	tracker.Close()
 }
 
@@ -29,7 +29,7 @@ func TestProgressTracking_multi_open_close(t *testing.T) {
 
 	for i := 0; i < 100; i++ {
 		g.Go(func() error {
-			tracker := bar.TrackProgress("file,", 1, 42, ioutil.NopCloser(nil))
+			tracker := bar.TrackProgress("file,", 1, 42, io.NopCloser(nil))
 			return tracker.Close()
 		})
 	}
@@ -46,7 +46,7 @@ func TestProgressTracking_races(t *testing.T) {
 		g.Go(func() error {
 			txt := []byte("foobarbaz dolores")
 			b := bytes.NewReader(txt)
-			tracker := bar.TrackProgress("file,", 1, 42, ioutil.NopCloser(b))
+			tracker := bar.TrackProgress("file,", 1, 42, io.NopCloser(b))
 
 			for i := 0; i < 42; i++ {
 				tracker.Read([]byte("i"))
