@@ -18,7 +18,7 @@ import (
 
 	"github.com/biogo/hts/bgzf"
 	"github.com/klauspost/pgzip"
-	"github.com/pierrec/lz4"
+	"github.com/pierrec/lz4/v4"
 	"github.com/ulikunitz/xz"
 )
 
@@ -190,7 +190,7 @@ func (c *Compressor) BenchmarkPGZIPReader(b *testing.B) {
 func (c *Compressor) BenchmarkLZ4Writer(b *testing.B) {
 	cw := lz4.NewWriter(c.w)
 	//	cw.Header.HighCompression = true
-	cw.Header.NoChecksum = true
+	cw.Apply(lz4.ChecksumOption(false))
 	b.ResetTimer()
 
 	_, err := io.Copy(cw, c.r)
