@@ -5,7 +5,7 @@ package shell_test
 
 import (
 	"fmt"
-	"io/ioutil"
+	"io"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -31,7 +31,7 @@ func loadFile(templateFragmentPath string) (string, error) {
 	}
 	defer fragmentFile.Close()
 
-	fragmentString, err := ioutil.ReadAll(fragmentFile)
+	fragmentString, err := io.ReadAll(fragmentFile)
 	if err != nil {
 		return "", fmt.Errorf("Unable to read %s", fragmentAbsPath)
 	}
